==> axis2-1.8.0-src.zip: axis2-1.8.0/modules/metadata/src/org/apache/axis2/jaxws/description/builder/RespectBindingAnnot.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.axis2.jaxws.description.builder;

import javax.xml.ws.RespectBinding;
import java.lang.annotation.Annotation;

public class RespectBindingAnnot implements RespectBinding {

    private boolean enabled = true;
    
    public boolean enabled() {
        return enabled;
    }
    
    public void setEnabled(boolean e) {
        enabled = e;
    }

    public Class<? extends Annotation> annotationType() {
        return RespectBinding.class;
    }
    
    public String toString() {
        String string = null;
        try {
            string = "@" + getClass().getName() 
                + "(enabled=" + enabled
                + ")";
        } catch (Throwable t) {
            string = super.toString() + ": caught exception in toString(): " + t;
        }
        return string;
    }

}

==> axis2-2.0.0-src.zip: axis2-2.0.0/modules/metadata/src/org/apache/axis2/jaxws/description/builder/RespectBindingAnnot.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.axis2.jaxws.description.builder;

import jakarta.xml.ws.RespectBinding;
import java.lang.annotation.Annotation;

public class RespectBindingAnnot implements RespectBinding {

    private boolean enabled = true;
    
    public boolean enabled() {
        return enabled;
    }
    
    public void setEnabled(boolean e) {
        enabled = e;
    }

    public Class<? extends Annotation> annotationType() {
        return RespectBinding.class;
    }
    
    public String toString() {
        String string = null;
        try {
            string = "@" + getClass().getName() 
                + "(enabled=" + enabled
                + ")";
        } catch (Throwable t) {
            string = super.toString() + ": caught exception in toString(): " + t;
        }
        return string;
    }

}
